InstalledRuleV4

Struct InstalledRuleV4 

pub struct InstalledRuleV4 {
    pub rule_set_priority: u32,
    pub rule_index: u32,
    pub matcher: RuleMatcherV4,
    pub action: RuleAction,
}
An installed IPv4 routing rule.

Fields

rule_set_priority: u32

Rule sets are ordered by the rule set priority, rule sets are disjoint and don’t have interleaving rules among them.

rule_index: u32

Rules within a rule set are locally ordered, together with the rule set priority, this defines a global order for all installed rules.

matcher: RuleMatcherV4

The matcher part of the rule, the rule is a no-op if the matcher does not match the packet.

action: RuleAction

The action part of the rule that describes what to do if the matcher matches the packet.